@@ -376,7 +376,10 @@ bool Document::prepareDownSampledImageForZoom(qreal zoom)
         return true;
     }
 
-    if (loadingState() == Loaded) {
+    if (loadingState() == LoadingFailed) {
+        kWarning() << "Image has failed to load, not doing anything";
+        return false;
+    } else if (loadingState() == Loaded) {
         // Resample image from the full one
         d->mDownSampledImageMap[invertedZoom] = d->mImage.scaled(d->mImage.size() / invertedZoom, Qt::KeepAspectRatio, Qt::FastTransformation);
         if (d->mDownSampledImageMap[invertedZoom].size().isEmpty()) {
